| pmml.rules | R Documentation |
Generate the PMML representation for a rules or an itemset object from package arules.
## S3 method for class 'rules'
pmml(
model,
model_name = "arules_Model",
app_name = "R PMML Generator - Package pmml",
description = "Association Rules Model",
copyright = NULL,
model_version = NULL,
transforms = NULL,
...
)
model |
A rules or itemsets object. |
model_name |
A name to be given to the PMML model. |
app_name |
The name of the application that generated the PMML. |
description |
A descriptive text for the Header element of the PMML. |
copyright |
The copyright notice for the model. |
model_version |
A string specifying the model version. |
transforms |
Data transformations. |
... |
Further arguments passed to or from other methods. |
The model is represented in the PMML AssociationModel format.
PMML representation of the rules or itemsets object.
Graham Williams, Michael Hahsler
arules: Mining Association Rules and Frequent Itemsets
## Not run:
library(arules)
data(Adult)
rules <- apriori(Adult, support = 0.5, confidence = 0.9)
rules_pmml <- pmml(rules)
rules_pmml
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.