Learn R Programming

pmml (version 2.6.0)

audit: Audit: artificially constructed dataset

Description

This is an artificial dataset consisting of fictional clients who have been audited, perhaps for tax refund compliance. For each case an outcome is recorded (whether the taxpayer's claims had to be adjusted or not) and any amount of adjustment that resulted is also recorded.

Arguments

Format

A data frame containing:

AgeNumeric
EmploymentCategorical string with 7 levels
EducationCategorical string with 16 levels
MaritalCategorical string with 6 levels
OccupationCategorical string with 14 levels
IncomeNumeric
SexCategorical string with 2 levels
DeductionsNumeric
HoursNumeric
AccountsCategorical string with 32 levels
AdjustmentNumeric
AdjustedNumeric value 0 or 1

References

Examples

Run this code
data(audit, package = "pmml")

Run the code above in your browser using DataLab