The 'closure' attribute of each 'Interval' element to be created in order.
leftMargin
The 'leftMargin' attribute of each 'Interval' element to be created in order.
rightMargin
The 'rightMargin' attribute of each 'Interval' element to be created in order.
namespace
The namespace of the PMML model
Author
Tridivesh Jena
Details
The 'Interval' element allows 3 attributes, all of which may be defined in the 'make_intervals'
function. The value of these attributes should be provided as a list. Thus the elements of the
'leftMargin' for example define the value of that attribute for each 'Interval' element in order.
See Also
make_values to make Values child elements, add_data_field_children
to add these xml fragments to the DataDictionary PMML element.