Learn R Programming

pmml (version 2.6.0)

pmml.lm: Generate the PMML representation for an lm object from the package stats.

Description

Generate the PMML representation for an lm object from the package stats.

Usage

# S3 method for lm
pmml(
  model,
  model_name = "lm_Model",
  app_name = "R PMML Generator - Package pmml",
  description = "Linear Regression Model",
  copyright = NULL,
  model_version = NULL,
  transforms = NULL,
  missing_value_replacement = NULL,
  weights = NULL,
  ...
)

Value

PMML representation of the lm object.

Arguments

model

An lm object.

model_name

A name to be given to the PMML model.

app_name

The name of the application that generated the PMML.

description

A descriptive text for the Header element of the PMML.

copyright

The copyright notice for the model.

model_version

A string specifying the model version.

transforms

Data transformations.

missing_value_replacement

Value to be used as the 'missingValueReplacement' attribute for all MiningFields.

weights

The weights used for building the model.

...

Further arguments passed to or from other methods.

Author

Rajarshi Guha

Details

The resulting PMML representation will not encode interaction terms. Currently, only numeric regression is supported.

References

R project: Fitting Linear Models

Examples

Run this code
if (FALSE) {
fit <- lm(Sepal.Length ~ ., data = iris)
fit_pmml <- pmml(fit)
}

Run the code above in your browser using DataLab