powered by
Generate the PMML representation for a nnet object from package nnet.
# S3 method for nnet pmml( model, model_name = "NeuralNet_model", app_name = "R PMML Generator - Package pmml", description = "Neural Network Model", copyright = NULL, model_version = NULL, transforms = NULL, missing_value_replacement = NULL, ... )
PMML representation of the nnet object.
A nnet object.
A name to be given to the PMML model.
The name of the application that generated the PMML.
A descriptive text for the Header element of the PMML.
The copyright notice for the model.
A string specifying the model version.
Data transformations.
Value to be used as the 'missingValueReplacement' attribute for all MiningFields.
Further arguments passed to or from other methods.
Tridivesh Jena
This function supports both regression and classification neural network models. The model is represented in the PMML NeuralNetwork format.
nnet: Feed-forward Neural Networks and Multinomial Log-Linear Models (on CRAN)
if (FALSE) { library(nnet) fit <- nnet(Species ~ ., data = iris, size = 4) fit_pmml <- pmml(fit) rm(fit) }
Run the code above in your browser using DataLab