powered by
Generate the PMML representation for a randomForest object from the package randomForest.
# S3 method for randomForest pmml( model, model_name = "randomForest_Model", app_name = "R PMML Generator - Package pmml", description = "Random Forest Tree Model", copyright = NULL, model_version = NULL, transforms = NULL, missing_value_replacement = NULL, parent_invalid_value_treatment = "returnInvalid", child_invalid_value_treatment = "asIs", ... )
PMML representation of the randomForest object.
A randomForest object.
A name to be given to the PMML model.
The name of the application that generated the PMML.
A descriptive text for the Header element of the PMML.
The copyright notice for the model.
A string specifying the model version.
Data transformations.
Value to be used as the 'missingValueReplacement' attribute for all MiningFields.
Invalid value treatment at the top MiningField level.
Invalid value treatment at the model segment MiningField level.
Further arguments passed to or from other methods.
Tridivesh Jena
This function outputs a Random Forest in PMML format.
randomForest: Breiman and Cutler's random forests for classification and regression
if (FALSE) { # Build a randomForest model library(randomForest) iris_rf <- randomForest(Species ~ ., data = iris, ntree = 20) # Convert to pmml iris_rf_pmml <- pmml(iris_rf) rm(iris_rf) }
Run the code above in your browser using DataLab