powered by
Generate the PMML representation for an rpart object from the package rpart.
# S3 method for rpart pmml( model, model_name = "RPart_Model", app_name = "R PMML Generator - Package pmml", description = "RPart Decision Tree Model", copyright = NULL, model_version = NULL, transforms = NULL, missing_value_replacement = NULL, dataset = NULL, ... )
PMML representation of the rpart object.
An rpart object.
A name to be given to the PMML model.
The name of the application that generated the PMML.
A descriptive text for the Header element of the PMML.
The copyright notice for the model.
A string specifying the model version.
Data transformations.
Value to be used as the 'missingValueReplacement' attribute for all MiningFields.
Data used to train the rpart model.
Further arguments passed to or from other methods.
Graham Williams
Supports regression tree as well as classification. The object is represented in the PMML TreeModel format.
rpart: Recursive Partitioning (on CRAN)
if (FALSE) { library(rpart) fit <- rpart(Species ~ ., data = iris) fit_pmml <- pmml(fit) }
Run the code above in your browser using DataLab