powered by
Generate the PMML representation for a rules or an itemset object from package arules.
# S3 method for rules pmml( model, model_name = "arules_Model", app_name = "R PMML Generator - Package pmml", description = "Association Rules Model", copyright = NULL, model_version = NULL, transforms = NULL, ... )
PMML representation of the rules or itemsets object.
A rules or itemsets object.
A name to be given to the PMML model.
The name of the application that generated the PMML.
A descriptive text for the Header element of the PMML.
The copyright notice for the model.
A string specifying the model version.
Data transformations.
Further arguments passed to or from other methods.
Graham Williams, Michael Hahsler
The model is represented in the PMML AssociationModel format.
arules: Mining Association Rules and Frequent Itemsets
if (FALSE) { library(arules) data(Adult) rules <- apriori(Adult, support = 0.5, confidence = 0.9) rules_pmml <- pmml(rules) rules_pmml }
Run the code above in your browser using DataLab